==> owncloud-news_5.3.8%2Bdfsg.orig.tar.gz: news-5.3.8/l10n/gl.php <==
<?php
$TRANSLATIONS = array(
"Feed contains invalid XML" => "A fonte contén XML incorrecto",
"Could not find a feed" => "Non foi posíbel atopar ningunha fonte",
"Detected feed format is not supported" => "O formato detectado da fonte non está admitido",
"SSL Certificate is invalid" => "Certificado SSL incorrecto",
"Website not found" => "Non foi atopado o sitio web",
"More redirects than allowed, aborting" => "Máis redireccionamentos dos permitidos, abortando",
"Bigger than maximum allowed size" => "Maior que o tamaño máximo permitido",
"Request timed out" => "Caducou a petición",
"Request failed, network connection unavailable!" => "A petición non se realizou, a conexión de rede non está dispoñíbel!",
"Request unauthorized. Are you logged in?" => "Petición non autorizada. Está vostede autenticado?",
"Request forbidden. Are you an admin?" => "Petición prohibida. É vostede un administrador?",
"Token expired or app not enabled! Reload the page!" => "Ou ben caducou a marca ou a aplicación nos está activada! Volva cargar a páxina!",
"Internal server error! Please check your " => "Produciuse un erro interno no servidor! Comprobe o seu",
"Request failed, ownCloud is in currently " => "Non se realizou a petición, ownCloud está agora con iso",
"Can not add feed: Exists already" => "Non é posíbel engadir a fonte: xa existe",
"Articles without feed" => "Artigos sen fonte",
"Can not add folder: Exists already" => "Non é posíbel engadir o cartafol: xa existe",
"Use ownCloud cron for updates" => "Utilice ownCloud cron para as actualizacións",
"Disable this if you run a custom updater such as the Python updater included in the app" => "Desactive isto se vostede executa un actualizador automático tal como o Python updater incluído na aplicación",
"Purge interval" => "Intervalo de depuración",
"Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" => "Cantidade mínima de segundos após eliminar as fontes e cartafoles da base de datos; os valores menores de 60 segundos son ignorados",
"Maximum read count per feed" => "Conta máxima de lidos por fonte",
"Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off completely" => "Define o número máximo de artigos que pode ler por fonte os cales non serán eliminados polo traballo de limpeza; se os artigos antigos reaparecen após lidos, incremente este valor; os valores negativos como -1 desactivan esta función completamente",
"Maximum redirects" => "Redireccionamentos máximos",
"How many redirects the feed fetcher should follow" => "Cantos redirecionamentos debe seguir o buscador de fontes",
"Maximum feed page size" => "Tamaño máximo da páxina da fonte",
"Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" => "Tamaño máximo da fonte en bytes. Se a páxina RSS/Atom é maior que este valor, a actualización cancelarase",
"Feed fetcher timeout" => "Caducidade do buscador",
"Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" => "Número máximo de segundos agardando por unha fonte RSS ou Atom para cargar; se lle leva máis tempo a actualización será cancelada",
"Explore Service URL" => "Examinar o URL de servizo",
"If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" => "Se é fornecido, este URL de servizo requirirase para amosar as fontes na sección de exame da fonte. Para amparar co servizo de exame propio, deixe baldeira esta entrada",
"Saved" => "Gardado",
"Download" => "Descargar",
"Close" => "Pechar",
"Ajax cron mode detected! Your feeds will not be updated correctly. It is recommended to either use the operating system cron or a custom updater." => "Detectouse o modo cron de Ajax! As súas fontes non se actualizarán correctamente. É recomendábel ben utilizar o cron do sistema operativo ou ben un actualizador personalizado.",
"How to set up the operating system cron" => "Cómo configurar o cron do sistema operativo",
"How to set up a custom updater (faster and no possible deadlock) " => "Cómo configurar un actualizador personalizado (máis rápido e sen posibilidade de bloqueo)",
"Subscribe" => "Subscribir",
"Refresh" => "Actualizar",
"No articles available" => "Non hai artigos dispoñíbeis",
"No unread articles available" => "Non hai artigos sen ler dispoñíbeis",
"Open website" => "Abrir sitio web",
"Star article" => "Marcar artigo",
"Unstar article" => "Desmarcar artigo",
"Keep article unread" => "Manter o artigo como non lido",
"Remove keep article unread" => "Retirar a marca de artigo sen ler",
"by" => "por",
"from" => "desde",
"Play audio" => "Reproducir son",
"Download video" => "Descargar video",
"Download audio" => "Descargar son",
"Keyboard shortcut" => "Atallo de teclado",
"Description" => "Descrición",
"right" => "dereita",
"Jump to next article" => "Ir ao seguinte artigo",
"left" => "esquerda",
"Jump to previous article" => "Saltar ao artigo anterior",
"Toggle star article" => "Amosar os artigos con estrela",
"Star article and jump to next one" => "Destacar o artigo e ir ao seguinte",
"Toggle keep current article unread" => "Manter o artigo actual como non lido",
"Open article in new tab" => "Abrir o artigo nunha nova lapela",
"Toggle expand article in compact view" => "Expandir o artigo en vista compacta",
"Load next feed" => "Cargar a seguinte fonte",
"Load previous feed" => "Cargar a fonte anterior",
"Load next folder" => "Cargar o seguinte cartafol",
"Load previous folder" => "Cargar o cartafol anterior",
"Scroll to active navigation entry" => "Desprazar ata a entrada de navegación activa",
"Focus search field" => "Campo de busca en foco",
"Mark current article's feed/folder read" => "Marcar o actual artigo de fonte/cartafol como lido",
"Web address" => "Enderezo web",
"Feed exists already!" => "Esta fonte de novas xa existe!",
"Folder" => "Cartafol",
"No folder" => "Sen cartafol",
"New folder" => "Novo cartafol",
"Folder name" => "Nome do cartafol",
"Go back" => "Volver",
"Folder exists already!" => "Xa existe o cartafol!",
"New Folder" => "Novo cartafol",
"Create" => "Crear",
"Explore" => "Examinar",
"Deleted feed" => "Fonte eliminada",
"Undo delete feed" => "Desfacer a eliminación da fonte",
"Rename" => "Renomear",
"Menu" => "Menú",
"No feed ordering" => "Fonte ser ordenadar",
"Reversed feed ordering" => "Ordenado inverso da fonte",
"Normal feed ordering" => "Ordenado normal da fonte",
"Rename feed" => "Renomear a fonte",
"Delete feed" => "Eliminar fonte de novas",
"Mark all articles read" => "Marcar todos os artigos como lidos",
"Dismiss" => "Desbotar",
"Collapse" => "Contraer",
"Deleted folder" => "Eliminar cartafol",
"Undo delete folder" => "Desfacer a eliminación do cartafol",
"Rename folder" => "Renomear o cartafol",
"Delete folder" => "Eliminar o cartafol",
"Starred" => "Destacado",
"Unread articles" => "Artigos sen ler",
"All articles" => "Todos os artigos",
"Settings" => "Axustes",
"Keyboard shortcuts" => "Atallos de teclado",
"Disable mark read through scrolling" => "Desactivar o marcado como lido co desprazamento",
"Compact view" => "Vista compacta",
"Expand articles on key navigation" => "Expandir artigos na tecla de navegación",
"Show all articles" => "Amosar todos os artigos",
"Reverse ordering (oldest on top)" => "Ordenado inverso (máis vellos enriba)",
"Subscriptions (OPML)" => "Subscricións (OPML)",
"Import" => "Importar",
"Export" => "Exportar",
"Error when importing: file does not contain valid OPML" => "Erro durante a importación: o ficheiro non conten OPML correcto",
"Unread/Starred Articles" => "Artigos destacados ou sen ler",
"Error when importing: file does not contain valid JSON" => "Produciuse un erro ao importar: o ficheiro non contén un JSON correcto"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud-news_7.0.1%2Bdfsg.orig.tar.gz: news-7.0.1/l10n/gl.php <==
<?php
$TRANSLATIONS = array(
"Feed contains invalid XML" => "A fonte contén XML incorrecto",
"Detected feed format is not supported" => "O formato detectado da fonte non está admitido",
"SSL Certificate is invalid" => "Certificado SSL incorrecto",
"Website not found" => "Non foi atopado o sitio web",
"More redirects than allowed, aborting" => "Máis redireccionamentos dos permitidos, cancelando",
"Bigger than maximum allowed size" => "Maior que o tamaño máximo permitido",
"Request timed out" => "Caducou a petición",
"Request failed, network connection unavailable!" => "A petición non se realizou, a conexión de rede non está dispoñíbel!",
"Request unauthorized. Are you logged in?" => "Petición non autorizada. Está vostede autenticado?",
"Request forbidden. Are you an admin?" => "Petición prohibida. É vostede un administrador?",
"Token expired or app not enabled! Reload the page!" => "Ou ben caducou a marca ou a aplicación nos está activada! Volva cargar a páxina!",
"Internal server error! Please check your " => "Produciuse un erro interno no servidor! Comprobe o seu",
"Request failed, ownCloud is in currently " => "Non se realizou a petición, ownCloud está agora con iso",
"Can not add feed: Exists already" => "Non é posíbel engadir a fonte: xa existe",
"Articles without feed" => "Artigos sen fonte",
"Can not add folder: Exists already" => "Non é posíbel engadir o cartafol: xa existe",
"Use ownCloud cron for updates" => "Utilice ownCloud cron para as actualizacións",
"Disable this if you run a custom updater such as the Python updater included in the app" => "Desactive isto se vostede executa un actualizador automático tal como o Python updater incluído na aplicación",
"Purge interval" => "Intervalo de depuración",
"Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" => "Cantidade mínima de segundos após eliminar as fontes e cartafoles da base de datos; os valores menores de 60 segundos son ignorados",
"Maximum read count per feed" => "Conta máxima de lidos por fonte",
"Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off completely" => "Define o número máximo de artigos que pode ler por fonte os cales non serán eliminados polo traballo de limpeza; se os artigos antigos reaparecen após lidos, incremente este valor; os valores negativos como -1 desactivan esta función completamente",
"Maximum redirects" => "Redireccionamentos máximos",
"How many redirects the feed fetcher should follow" => "Cantos redirecionamentos debe seguir o buscador de fontes",
"Maximum feed page size" => "Tamaño máximo da páxina da fonte",
"Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" => "Tamaño máximo da fonte en bytes. Se a páxina RSS/Atom é maior que este valor, a actualización cancelarase",
"Feed fetcher timeout" => "Caducidade do buscador",
"Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" => "Número máximo de segundos agardando por unha fonte RSS ou Atom para cargar; se lle leva máis tempo a actualización será cancelada",
"Explore Service URL" => "Examinar o URL de servizo",
"If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" => "Se é fornecido, este URL de servizo requirirase para amosar as fontes na sección de exame da fonte. Para amparar co servizo de exame propio, deixe baldeira esta entrada",
"Saved" => "Gardado",
"Download" => "Descargar",
"Close" => "Pechar",
"Ajax or webcron cron mode detected! Your feeds will not be updated correctly. It is recommended to either use the operating system cron or a custom updater." => "Detectouse o modo cron de Ajax ou de webcron! As súas fontes non se actualizarán correctamente. É recomendábel ben utilizar o cron do sistema operativo ou ben un actualizador personalizado.",
"How to set up the operating system cron" => "Cómo configurar o cron do sistema operativo",
"How to set up a custom updater (faster and no possible deadlock) " => "Cómo configurar un actualizador personalizado (máis rápido e sen posibilidade de bloqueo)",
"Subscribe" => "Subscribir",
"Refresh" => "Actualizar",
"No articles available" => "Non hai artigos dispoñíbeis",
"No unread articles available" => "Non hai artigos sen ler dispoñíbeis",
"Open website" => "Abrir sitio web",
"Star article" => "Marcar artigo",
"Unstar article" => "Desmarcar artigo",
"Keep article unread" => "Manter o artigo como non lido",
"Remove keep article unread" => "Retirar a marca de artigo sen ler",
"by" => "por",
"from" => "desde",
"Play audio" => "Reproducir son",
"Download video" => "Descargar video",
"Download audio" => "Descargar son",
"Keyboard shortcut" => "Atallo de teclado",
"Description" => "Descrición",
"right" => "dereita",
"Jump to next article" => "Ir ao seguinte artigo",
"left" => "esquerda",
"Jump to previous article" => "Saltar ao artigo anterior",
"Toggle star article" => "Amosar os artigos con estrela",
"Star article and jump to next one" => "Destacar o artigo e ir ao seguinte",
"Toggle keep current article unread" => "Manter o artigo actual como non lido",
"Open article in new tab" => "Abrir o artigo nunha nova lapela",
"Toggle expand article in compact view" => "Expandir o artigo en vista compacta",
"Load next feed" => "Cargar a seguinte fonte",
"Load previous feed" => "Cargar a fonte anterior",
"Load next folder" => "Cargar o seguinte cartafol",
"Load previous folder" => "Cargar o cartafol anterior",
"Scroll to active navigation entry" => "Desprazar ata a entrada de navegación activa",
"Focus search field" => "Campo de busca en foco",
"Mark current article's feed/folder read" => "Marcar o actual artigo de fonte/cartafol como lido",
"Web address" => "Enderezo web",
"Feed exists already!" => "Esta fonte de novas xa existe!",
"Folder" => "Cartafol",
"No folder" => "Sen cartafol",
"New folder" => "Novo cartafol",
"Folder name" => "Nome do cartafol",
"Go back" => "Volver",
"Folder exists already!" => "Xa existe o cartafol!",
"New Folder" => "Novo cartafol",
"Create" => "Crear",
"Explore" => "Examinar",
"Deleted feed" => "Fonte eliminada",
"Undo delete feed" => "Desfacer a eliminación da fonte",
"Rename" => "Renomear",
"Menu" => "Menú",
"No feed ordering" => "Fonte ser ordenadar",
"Reversed feed ordering" => "Ordenado inverso da fonte",
"Normal feed ordering" => "Ordenado normal da fonte",
"Rename feed" => "Renomear a fonte",
"Delete feed" => "Eliminar fonte de novas",
"Mark all articles read" => "Marcar todos os artigos como lidos",
"Dismiss" => "Desbotar",
"Collapse" => "Contraer",
"Deleted folder" => "Eliminar cartafol",
"Undo delete folder" => "Desfacer a eliminación do cartafol",
"Rename folder" => "Renomear o cartafol",
"Delete folder" => "Eliminar o cartafol",
"Starred" => "Destacado",
"Unread articles" => "Artigos sen ler",
"All articles" => "Todos os artigos",
"Settings" => "Axustes",
"Keyboard shortcuts" => "Atallos de teclado",
"Disable mark read through scrolling" => "Desactivar o marcado como lido co desprazamento",
"Compact view" => "Vista compacta",
"Expand articles on key navigation" => "Expandir artigos na tecla de navegación",
"Show all articles" => "Amosar todos os artigos",
"Reverse ordering (oldest on top)" => "Ordenado inverso (máis vellos enriba)",
"Subscriptions (OPML)" => "Subscricións (OPML)",
"Import" => "Importar",
"Export" => "Exportar",
"Error when importing: file does not contain valid OPML" => "Erro durante a importación: o ficheiro non conten OPML correcto",
"Unread/Starred Articles" => "Artigos destacados ou sen ler",
"Error when importing: file does not contain valid JSON" => "Produciuse un erro ao importar: o ficheiro non contén un JSON correcto"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
